==> haskell-binary-conduit-1.3.1-502-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-6OjhiK7dNpIJinCbsON9xV
key:                  binary-conduit-1.3.1-6OjhiK7dNpIJinCbsON9xV
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  e7008bf073e71e69b75a978c45133f6d
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-6OjhiK7dNpIJinCbsON9xV
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT exceptions-0.10.5
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-503-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-GJHDpxYtbCsFPQtu6qW5md
key:                  binary-conduit-1.3.1-GJHDpxYtbCsFPQtu6qW5md
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  cf375c957935c5d595f501d49e034799
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-GJHDpxYtbCsFPQtu6qW5md
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-LsCA1bXaHAtCkLdZq4D2B7 exceptions-0.10.5
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
